.. :changelog:

История изменений
-----------------
0.1.2
++++++
- Убрано отображение нового значения в окне детального просмотра истории, если у истории тип изменения "Удаление".
0.1.1
++++++
- Добавлена обработка нового пути детального просмотра записи истории.
- Добавлена обработка предыдущего значения при просмотре определенной (выбранной) истории.

0.1.0
++++++
- Расширен набор фильтров